#include <iostream>

typedef unsigned long long ull;

using namespace std;

// The sum of all digits of all numbers from 0 to n,
// there may be slightly simpler ways to do this but probably not much simpler.
ull digit_sum(ull n) {
    if (n == 0) return 0;

    ull pow10 = 1, digits = 1;
    while (pow10*10 <= n) {
        pow10 *= 10;
        ++digits;
    }

    /* Count the digit_sum for numbers 0 through pow10-1
       this is easy as each digit appears exactly pow10/10 times in
       each position. Here, 45 is the sum of digits 1 through 9.
    */
    ull p10_sum = (pow10/10)*(digits-1)*45;

    ull lead_digit = n/pow10;

    /* Now compute the digit sum for all numbers up to lead_digit*pow10-1
       eg. if n == 527 this computes the digit sum of all numbers from 0 to 499

       Method: The p10_sum is counted for each digit from 0 to lead_digit-1,
               this counts all digits except the leading digits for this range
               (eg. this counts all digits in 000 to 499 except the leading digits
               of each number).

               To count the leading digits, each will be counted
               pow10 times exactly. So compute pow10 * the sum of digits up to
               (but not including) lead_digit, eg. 0+1+2+3+4 in our example.

               This last term is lead_digit*(lead_digit-1)/2.
    */

    ull ans = lead_digit*p10_sum + pow10 * lead_digit*(lead_digit-1)/2;

    /* To count remaining numbers delete the leading digit and recurse.

       eg. if n == 527 then to compute the digit sum for 500 through 527
       we compute the digit sum for 0 through 27 recursively and add 5*28
       for the leading 5 we chopped off (as there are 28 numbers from 0 to 27).
    */
    ull res = n%pow10;
    return ans + digit_sum(res) + lead_digit*(res+1);
}

int main() {
    int cases;
    cin >> cases;
    while (cases--) {
        ull a, b;
        cin >> a >> b;
        cout << digit_sum(b) - (a?digit_sum(a-1):0) << endl;
    }

    return 0;
}
